Crate kcr_devices_kubeedge_io

Crate kcr_devices_kubeedge_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the devices.kubeedge.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

devices.kubeedge.io/v1alpha2

  • DeviceModel
  • Device

devices.kubeedge.io/v1beta1

  • DeviceModel
  • Device

Modules

v1alpha2
v1beta1